# Generated by Django 3.1 on 2021-01-08 11:42

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('proxypay', '0004_reference_paid_at'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='reference',
            name='payment_status',
        ),
        migrations.AddField(
            model_name='reference',
            name='status',
            field=models.CharField(default=0, editable=False, max_length=10),
        ),
        migrations.AlterField(
            model_name='reference',
            name='reference',
            field=models.IntegerField(editable=False, verbose_name='Reference'),
        ),
    ]
