# Generated by Django 3.0.5 on 2020-05-12 10:03

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('proxypay', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='reference',
            name='expires_in',
            field=models.DateTimeField(default=None, null=True),
        ),
    ]
