# Generated by Django 3.0.5 on 2020-05-11 10:56

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Reference',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('reference', models.IntegerField(editable=False, unique=True, verbose_name='Reference')),
                ('amount', models.DecimalField(decimal_places=2, editable=False, max_digits=12, verbose_name='Amount')),
                ('entity', models.CharField(default=None, editable=False, max_length=100, null=True, verbose_name='Entity')),
                ('custom_fields_text', models.TextField(default='', editable=False)),
                ('payment_status', models.CharField(default='wait', editable=False, max_length=10)),
                ('payment_data_text', models.TextField(default=None, editable=False, null=True)),
                ('created_at', models.DateTimeField(auto_now_add=True, verbose_name='Created At')),
                ('updated_at', models.DateTimeField(auto_now=True, verbose_name='Update At')),
            ],
        ),
    ]
