# Generated by Django 3.1 on 2020-10-25 21:10

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('proxypay', '0002_reference_expires_in'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='reference',
            name='custom_fields_text',
        ),
        migrations.RemoveField(
            model_name='reference',
            name='payment_data_text',
        ),
        migrations.AddField(
            model_name='reference',
            name='fields',
            field=models.JSONField(default=dict),
        ),
        migrations.AddField(
            model_name='reference',
            name='is_paid',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='reference',
            name='payment',
            field=models.JSONField(default=None, null=True),
        ),
    ]
