# Generated by Django 3.1 on 2020-10-26 17:40

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('proxypay', '0003_auto_20201025_2110'),
    ]

    operations = [
        migrations.AddField(
            model_name='reference',
            name='paid_at',
            field=models.DateTimeField(default=None, null=True),
        ),
    ]
